==> nextcloud-19.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/text/l10n/nb.js <==
OC.L10N.register(
    "text",
    {
    "Nextcloud Text" : "Nextcloud Text",
    "text document" : "tekstdokument",
    "Text" : "Tekst",
    "📝 Collaborative document editing" : "Dokumentredigering med samarbeidspartnere",
    "Use current version" : "Bruk siste versjon",
    "Use the saved version" : "Bruk lagret versjon",
    "The document has been changed outside of the editor. The changes cannot be applied." : "Dokumentet har blitt endret utenfor programmet. Endringene kan ikke benyttes. ",
    "File could not be loaded. Please check your internet connection." : "Filen kunne ikke lastes. Vennligst sjekk internettforbindelsen din. ",
    "Retry" : "Prøv igjen",
    "Last saved {lastSaved}" : "Sist lagret {lastSaved}",
    "Unsaved changes" : "Ulagrede endringer",
    "Enter your name so other users can see who is editing" : "Skriv inn navnet ditt slik at andre brukere kan se hvem som redigerer",
    "Edit guest name" : "Rediger gjestenavn",
    "Save guest name" : "Lagre gjestenavn",
    "Insert image" : "Sett inn bilde",
    "Add link" : "Legg ved lenke",
    "_and %n other editor_::_and %n other editors_" : ["og %nannet redigeringsprogram","og %n andre redigeringsprogrammer"],
    "Add notes, lists or links …" : "Legg til notater, lister eller lenker ...",
    "New text document" : "Nytt tekstdokument",
    "Edit" : "Rediger",
    "Undo" : "Angre",
    "Redo" : "Gjør om",
    "Bold" : "Uthevet",
    "Italic" : "Kursiv",
    "Strikethrough" : "Gjennomstreking",
    "Paragraph" : "Paragraf",
    "Headings" : "Overskrifter",
    "Heading 1" : "Overskrift 1",
    "Heading 2" : "Overskrift 2",
    "Heading 3" : "Overskrift 3",
    "Heading 4" : "Overskrift 4",
    "Heading 5" : "Overskrift 5",
    "Heading 6" : "Overskrift 6",
    "Unordered list" : "Uordnet liste",
    "Ordered list" : "Ordnet liste",
    "ToDo list" : "Gjøreliste",
    "Code block" : "Kodeseksjon",
    "Network connection error: Could not connect to the document" : "Nettverksfeil: Kunne ikke koble til dokumentet",
    "Last save {lastSave}" : "Sist lagret {lastSave}",
    "Show image" : "Vis bilde",
    "Show file" : "Vis fil"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-20.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/text/l10n/nb.js <==
OC.L10N.register(
    "text",
    {
    "Nextcloud Text" : "Nextcloud Text",
    "text document" : "tekstdokument",
    "Readme" : "Lesmeg",
    "Text" : "Tekst",
    "📝 Collaborative document editing" : "Dokumentredigering med samarbeidspartnere",
    "Use current version" : "Bruk siste versjon",
    "Use the saved version" : "Bruk lagret versjon",
    "The document has been changed outside of the editor. The changes cannot be applied." : "Dokumentet har blitt endret utenfor programmet. Endringene kan ikke benyttes. ",
    "File could not be loaded. Please check your internet connection." : "Filen kunne ikke lastes. Vennligst sjekk internettforbindelsen din. ",
    "Retry" : "Prøv igjen",
    "Last saved {lastSaved}" : "Sist lagret {lastSaved}",
    "Unpushed changes" : "Ulagrede endringer",
    "Unsaved changes" : "Ulagrede endringer",
    "Enter your name so other users can see who is editing" : "Skriv inn navnet ditt slik at andre brukere kan se hvem som redigerer",
    "Edit guest name" : "Rediger gjestenavn",
    "Save guest name" : "Lagre gjestenavn",
    "Insert image" : "Sett inn bilde",
    "_and %n other editor_::_and %n other editors_" : ["og %nannet redigeringsprogram","og %n andre redigeringsprogrammer"],
    "Show rich workspaces" : "Vis arbeidsområde",
    "Add notes, lists or links …" : "Legg til notater, lister eller lenker ...",
    "New text document" : "Nytt tekstdokument",
    "Edit" : "Rediger",
    "Undo" : "Angre",
    "Redo" : "Gjør om",
    "Bold" : "Uthevet",
    "Italic" : "Kursiv",
    "Strikethrough" : "Gjennomstreking",
    "Headings" : "Overskrifter",
    "Heading 1" : "Overskrift 1",
    "Heading 2" : "Overskrift 2",
    "Heading 3" : "Overskrift 3",
    "Heading 4" : "Overskrift 4",
    "Heading 5" : "Overskrift 5",
    "Heading 6" : "Overskrift 6",
    "Unordered list" : "Uordnet liste",
    "Ordered list" : "Ordnet liste",
    "ToDo list" : "Gjøreliste",
    "Blockquote" : "Sitat",
    "Code block" : "Kode",
    "Last save {lastSave}" : "Sist lagret {lastSave}",
    "Add link" : "Legg ved lenke",
    "Show image" : "Vis bilde",
    "Show file" : "Vis fil",
    "Paragraph" : "Paragraf"
},
"nplurals=2; plural=(n != 1);");
